<?php
/**
 * @license MIT
 *
 * Modified by storeabill on 27-February-2024 using {@see https://github.com/BrianHenryIE/strauss}.
 */

namespace Vendidero\StoreaBill\Vendor\DeepCopy\Filter\Doctrine;

use Vendidero\StoreaBill\Vendor\DeepCopy\Filter\Filter;
use Vendidero\StoreaBill\Vendor\DeepCopy\Reflection\ReflectionHelper;

/**
 * @final
 */
class DoctrineCollectionFilter implements Filter
{
    /**
     * Copies the object property doctrine collection.
     *
     * {@inheritdoc}
     */
    public function apply($object, $property, $objectCopier)
    {
        $reflectionProperty = ReflectionHelper::getProperty($object, $property);

        $reflectionProperty->setAccessible(true);
        $oldCollection = $reflectionProperty->getValue($object);

        $newCollection = $oldCollection->map(
            function ($item) use ($objectCopier) {
                return $objectCopier($item);
            }
        );

        $reflectionProperty->setValue($object, $newCollection);
    }
}
