<?php

namespace Vendidero\StoreaBill;

use Vendidero\EUTaxHelper\Helper;

defined( 'ABSPATH' ) || exit;

class Countries {

	/**
	 * @return array|string[]
	 */
	public static function get_base_location() {
		return wc_get_base_location();
	}

	public static function get_base_country() {
		return self::get_base_location()['country'];
	}

	public static function base_country_supports_oss_procedure() {
		return apply_filters( 'storeabill_base_country_supports_oss_procedure', self::base_country_is_eu() );
	}

	public static function base_country_is_eu() {
		$base_country     = self::get_base_country();
		$eu_vat_countries = self::get_eu_vat_countries();

		return apply_filters( 'storeabill_base_country_is_eu', in_array( $base_country, $eu_vat_countries, true ) );
	}

	public static function get_base_state() {
		return self::get_base_location()['state'];
	}

	public static function get_base_address() {
		return WC()->countries->get_base_address();
	}

	public static function get_base_address_2() {
		return WC()->countries->get_base_address_2();
	}

	public static function get_base_city() {
		return WC()->countries->get_base_city();
	}

	public static function get_base_postcode() {
		return WC()->countries->get_base_postcode();
	}

	public static function get_base_company_name() {
		return get_bloginfo( 'name' );
	}

	public static function get_base_email() {
		return get_option( 'admin_email' );
	}

	public static function get_base_bank_account_data() {
		$data = array(
			'holder'    => Package::get_setting( 'bank_account_holder' ),
			'bank_name' => Package::get_setting( 'bank_account_bank_name' ),
			'iban'      => Package::get_setting( 'bank_account_iban' ),
			'bic'       => Package::get_setting( 'bank_account_bic' ),
		);

		$fallback_accounts = get_option( 'woocommerce_bacs_accounts' );

		if ( empty( $data['iban'] ) && ! empty( $fallback_accounts ) ) {
			$default_data = wp_parse_args(
				$fallback_accounts[0],
				array(
					'iban'         => '',
					'account_name' => '',
					'bank_name'    => '',
					'bic'          => '',
				)
			);

			$default_data['holder'] = $default_data['account_name'];

			foreach ( $data as $key => $value ) {
				if ( empty( $value ) ) {
					$data[ $key ] = $default_data[ $key ];
				}
			}
		}

		return $data;
	}

	public static function has_base_bank_account() {
		$data = self::get_base_bank_account_data();

		return ! empty( $data['iban'] ) ? true : false;
	}

	public static function get_base_address_data( $include_company = true ) {
		$address_data = array(
			'company'   => $include_company ? self::get_base_company_name() : '',
			'address_1' => self::get_base_address(),
			'address_2' => self::get_base_address_2(),
			'postcode'  => self::get_base_postcode(),
			'city'      => self::get_base_city(),
			'country'   => self::get_base_country(),
			'state'     => self::get_base_state(),
		);

		return apply_filters( 'storeabill_base_address_data', $address_data );
	}

	public static function get_formatted_base_address( $separator = '<br/>', $include_company = true ) {
		return self::get_formatted_address( self::get_base_address_data( $include_company ), $separator );
	}

	public static function get_formatted_address( $address = array(), $separator = '<br/>' ) {
		$force = apply_filters( 'storeabill_document_address_force_country_display', false );

		if ( $force ) {
			add_filter( 'woocommerce_formatted_address_force_country_display', '__return_true', 1, 2000 );
		}

		$formatted_address = WC()->countries->get_formatted_address( $address, $separator );

		if ( $force ) {
			remove_filter( 'woocommerce_formatted_address_force_country_display', '__return_true', 2000 );
		}

		return $formatted_address;
	}

	public static function is_third_country( $country, $postcode = '' ) {
		return apply_filters( 'storeabill_is_third_country', Helper::is_third_country( $country, $postcode ), $country, $postcode );
	}

	public static function get_eu_countries() {
		return Helper::get_eu_countries();
	}

	public static function get_eu_vat_countries() {
		return apply_filters( 'storeabill_eu_vat_countries', Helper::get_eu_vat_countries() );
	}

	public static function is_northern_ireland( $country, $postcode = '' ) {
		return Helper::is_northern_ireland( $country, $postcode );
	}

	public static function is_eu_vat_postcode_exemption( $country, $postcode = '' ) {
		return Helper::is_eu_vat_postcode_exemption( $country, $postcode );
	}

	public static function is_eu_vat_country( $country, $postcode = '' ) {
		$is_eu_vat_country = Helper::is_eu_vat_country( $country, $postcode );

		return apply_filters( 'storeabill_is_eu_vat_country', $is_eu_vat_country, $country, $postcode );
	}

	public static function get_eu_vat_postcode_exemptions() {
		return apply_filters( 'storeabill_eu_vat_postcode_exemptions', Helper::get_vat_postcode_exemptions() );
	}

	public static function is_eu_country( $country ) {
		return in_array( $country, self::get_eu_countries(), true );
	}
}
