<?php

namespace Vendidero\Germanized\DPD\ShippingProvider\Services;

use Vendidero\Germanized\Shipments\Labels\ConfigurationSet;
use Vendidero\Germanized\Shipments\ShipmentError;
use Vendidero\Germanized\Shipments\ShippingProvider\Service;

defined( 'ABSPATH' ) || exit;

class HigherInsurance extends Service {

	public function __construct( $shipping_provider, $args = array() ) {
		$args = array(
			'id'    => 'higher_insurance',
			'label' => _x( 'Higher Insurance', 'dpd', 'woocommerce-germanized-pro' ),
		);

		parent::__construct( $shipping_provider, $args );
	}

	public function get_default_value( $suffix = '' ) {
		$default_value = parent::get_default_value( $suffix );

		if ( 'amount' === $suffix ) {
			$default_value = '';
		} elseif ( 'description' === $suffix ) {
			$default_value = '';
		}

		return $default_value;
	}

	protected function get_additional_label_fields( $shipment ) {
		$label_fields = parent::get_additional_label_fields( $shipment );
		$value        = $shipment->get_total() + round( $shipment->get_additional_total(), wc_get_price_decimals() );

		$label_fields = array_merge(
			$label_fields,
			array(
				array(
					'id'                => $this->get_label_field_id( 'amount' ),
					'class'             => 'wc_input_decimal',
					'data_type'         => 'price',
					'label'             => _x( 'Amount', 'dpd', 'woocommerce-germanized-pro' ),
					'placeholder'       => '',
					'description'       => '',
					'value'             => wc_format_localized_decimal( $value ),
					'type'              => 'text',
					'custom_attributes' => array( 'data-show-if-service_higher_insurance' => '' ),
				),
				array(
					'id'                => $this->get_label_field_id( 'description' ),
					'label'             => _x( 'Description', 'dpd', 'woocommerce-germanized-pro' ),
					'placeholder'       => '',
					'description'       => '',
					'value'             => '',
					'type'              => 'text',
					'custom_attributes' => array(
						'data-show-if-service_higher_insurance' => '',
						'maxlength' => 35,
					),
				),
			)
		);

		return $label_fields;
	}
}
